package com.flask.colorpicker.builder;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.graphics.drawable.ColorDrawable;
import android.text.InputFilter;
import android.view.View;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.LinearLayout;
import com.androlua.R;
import com.androlua.util.TieUtils;
import com.flask.colorpicker.ColorPickerView;
import com.flask.colorpicker.OnColorChangedListener;
import com.flask.colorpicker.OnColorSelectedListener;
import com.flask.colorpicker.Utils;
import com.flask.colorpicker.renderer.ColorWheelRenderer;
import com.flask.colorpicker.slider.AlphaSlider;
import com.flask.colorpicker.slider.LightnessSlider;
/* loaded from: classes.dex */
public class ColorPickerDialogBuilder {
    private AlphaSlider alphaSlider;
    private AlertDialog.Builder builder;
    private EditText colorEdit;
    private ColorPickerView colorPickerView;
    private LinearLayout colorPreview;
    private int defaultMargin;
    private Integer[] initialColor;
    private boolean isAlphaSliderEnabled;
    private boolean isColorEditEnabled;
    private boolean isLightnessSliderEnabled;
    private boolean isPreviewEnabled;
    private LightnessSlider lightnessSlider;
    private LinearLayout pickerContainer;
    private int pickerCount;

    private ColorPickerDialogBuilder(Context context) {
        this(context, 0);
    }

    private ColorPickerDialogBuilder(Context context, int theme) {
        this.isLightnessSliderEnabled = true;
        this.isAlphaSliderEnabled = true;
        this.isColorEditEnabled = false;
        this.isPreviewEnabled = false;
        this.pickerCount = 1;
        this.defaultMargin = 0;
        this.initialColor = new Integer[]{null, null, null, null, null};
        this.defaultMargin = getDimensionAsPx(context, R.dimen.default_slider_margin);
        int dialogMarginBetweenTitle = getDimensionAsPx(context, R.dimen.default_slider_margin_btw_title);
        this.builder = new AlertDialog.Builder(context, theme);
        this.pickerContainer = new LinearLayout(context);
        this.pickerContainer.setOrientation(1);
        this.pickerContainer.setGravity(1);
        this.pickerContainer.setPadding(this.defaultMargin, dialogMarginBetweenTitle, this.defaultMargin, 0);
        LinearLayout.LayoutParams layoutParamsForColorPickerView = new LinearLayout.LayoutParams(-1, 0);
        layoutParamsForColorPickerView.weight = 1.0f;
        this.colorPickerView = new ColorPickerView(context);
        this.pickerContainer.addView(this.colorPickerView, layoutParamsForColorPickerView);
        this.builder.setView(this.pickerContainer);
    }

    public static ColorPickerDialogBuilder with(Context context) {
        return new ColorPickerDialogBuilder(context);
    }

    public static ColorPickerDialogBuilder with(Context context, int theme) {
        return new ColorPickerDialogBuilder(context, theme);
    }

    public ColorPickerDialogBuilder setTitle(String title) {
        this.builder.setTitle(title);
        return this;
    }

    public ColorPickerDialogBuilder setTitle(int titleId) {
        this.builder.setTitle(titleId);
        return this;
    }

    public ColorPickerDialogBuilder initialColor(int initialColor) {
        this.initialColor[0] = Integer.valueOf(initialColor);
        return this;
    }

    public ColorPickerDialogBuilder initialColors(int[] initialColor) {
        for (int i = 0; i < initialColor.length && i < this.initialColor.length; i++) {
            this.initialColor[i] = Integer.valueOf(initialColor[i]);
        }
        return this;
    }

    public ColorPickerDialogBuilder wheelType(ColorPickerView.WHEEL_TYPE wheelType) {
        ColorWheelRenderer renderer = ColorWheelRendererBuilder.getRenderer(wheelType);
        this.colorPickerView.setRenderer(renderer);
        return this;
    }

    public ColorPickerDialogBuilder density(int density) {
        this.colorPickerView.setDensity(density);
        return this;
    }

    public ColorPickerDialogBuilder setOnColorChangedListener(OnColorChangedListener onColorChangedListener) {
        this.colorPickerView.addOnColorChangedListener(onColorChangedListener);
        return this;
    }

    public ColorPickerDialogBuilder setOnColorSelectedListener(OnColorSelectedListener onColorSelectedListener) {
        this.colorPickerView.addOnColorSelectedListener(onColorSelectedListener);
        return this;
    }

    public ColorPickerDialogBuilder setPositiveButton(CharSequence text, final ColorPickerClickListener onClickListener) {
        this.builder.setPositiveButton(text, new DialogInterface.OnClickListener() { // from class: com.flask.colorpicker.builder.ColorPickerDialogBuilder.1
            @Override // android.content.DialogInterface.OnClickListener
            public void onClick(DialogInterface dialog, int which) {
                ColorPickerDialogBuilder.this.positiveButtonOnClick(dialog, onClickListener);
            }
        });
        return this;
    }

    public ColorPickerDialogBuilder setPositiveButton(int textId, final ColorPickerClickListener onClickListener) {
        this.builder.setPositiveButton(textId, new DialogInterface.OnClickListener() { // from class: com.flask.colorpicker.builder.ColorPickerDialogBuilder.2
            @Override // android.content.DialogInterface.OnClickListener
            public void onClick(DialogInterface dialog, int which) {
                ColorPickerDialogBuilder.this.positiveButtonOnClick(dialog, onClickListener);
            }
        });
        return this;
    }

    public ColorPickerDialogBuilder setNegativeButton(CharSequence text, DialogInterface.OnClickListener onClickListener) {
        this.builder.setNegativeButton(text, onClickListener);
        return this;
    }

    public ColorPickerDialogBuilder setNegativeButton(int textId, DialogInterface.OnClickListener onClickListener) {
        this.builder.setNegativeButton(textId, onClickListener);
        return this;
    }

    public ColorPickerDialogBuilder setNeutralButton(CharSequence text, DialogInterface.OnClickListener onClickListener) {
        this.builder.setNeutralButton(text, onClickListener);
        return this;
    }

    public ColorPickerDialogBuilder noSliders() {
        this.isLightnessSliderEnabled = false;
        this.isAlphaSliderEnabled = false;
        return this;
    }

    public ColorPickerDialogBuilder alphaSliderOnly() {
        this.isLightnessSliderEnabled = false;
        this.isAlphaSliderEnabled = true;
        return this;
    }

    public ColorPickerDialogBuilder lightnessSliderOnly() {
        this.isLightnessSliderEnabled = true;
        this.isAlphaSliderEnabled = false;
        return this;
    }

    public ColorPickerDialogBuilder showAlphaSlider(boolean showAlpha) {
        this.isAlphaSliderEnabled = showAlpha;
        return this;
    }

    public ColorPickerDialogBuilder showLightnessSlider(boolean showLightness) {
        this.isLightnessSliderEnabled = showLightness;
        return this;
    }

    public ColorPickerDialogBuilder showColorEdit(boolean showEdit) {
        this.isColorEditEnabled = showEdit;
        return this;
    }

    public ColorPickerDialogBuilder setColorEditTextColor(int argb) {
        this.colorPickerView.setColorEditTextColor(argb);
        return this;
    }

    public ColorPickerDialogBuilder showColorPreview(boolean showPreview) {
        this.isPreviewEnabled = showPreview;
        if (!showPreview) {
            this.pickerCount = 1;
        }
        return this;
    }

    public ColorPickerDialogBuilder setPickerCount(int pickerCount) throws IndexOutOfBoundsException {
        if (pickerCount < 1 || pickerCount > 5) {
            throw new IndexOutOfBoundsException("Picker Can Only Support 1-5 Colors");
        }
        this.pickerCount = pickerCount;
        if (this.pickerCount > 1) {
            this.isPreviewEnabled = true;
        }
        return this;
    }

    public int getSelectedColor() {
        return this.colorPickerView.getSelectedColor();
    }

    public AlertDialog build() {
        Context context = this.builder.getContext();
        this.colorPickerView.setInitialColors(this.initialColor, getStartOffset(this.initialColor).intValue());
        if (this.isLightnessSliderEnabled) {
            LinearLayout.LayoutParams layoutParamsForLightnessBar = new LinearLayout.LayoutParams(-1, getDimensionAsPx(context, R.dimen.default_slider_height));
            this.lightnessSlider = new LightnessSlider(context);
            this.lightnessSlider.setLayoutParams(layoutParamsForLightnessBar);
            this.pickerContainer.addView(this.lightnessSlider);
            this.colorPickerView.setLightnessSlider(this.lightnessSlider);
            this.lightnessSlider.setColor(getStartColor(this.initialColor));
        }
        if (this.isAlphaSliderEnabled) {
            LinearLayout.LayoutParams layoutParamsForAlphaBar = new LinearLayout.LayoutParams(-1, getDimensionAsPx(context, R.dimen.default_slider_height));
            this.alphaSlider = new AlphaSlider(context);
            this.alphaSlider.setLayoutParams(layoutParamsForAlphaBar);
            this.pickerContainer.addView(this.alphaSlider);
            this.colorPickerView.setAlphaSlider(this.alphaSlider);
            this.alphaSlider.setColor(getStartColor(this.initialColor));
        }
        if (this.isColorEditEnabled) {
            LinearLayout.LayoutParams layoutParamsForColorEdit = new LinearLayout.LayoutParams(-1, -2);
            layoutParamsForColorEdit.setMargins(TieUtils.dip2px(context, 6.0f), 0, TieUtils.dip2px(context, 6.0f), 0);
            this.colorEdit = (EditText) View.inflate(context, R.layout.picker_edit, null);
            this.colorEdit.setFilters(new InputFilter[]{new InputFilter.AllCaps()});
            this.colorEdit.setSingleLine(true);
            this.colorEdit.setGravity(17);
            this.colorEdit.setVisibility(8);
            int maxLength = this.isAlphaSliderEnabled ? 9 : 7;
            this.colorEdit.setFilters(new InputFilter[]{new InputFilter.LengthFilter(maxLength)});
            this.pickerContainer.addView(this.colorEdit, layoutParamsForColorEdit);
            this.colorEdit.setText(Utils.getHexString(getStartColor(this.initialColor), this.isAlphaSliderEnabled));
            this.colorPickerView.setColorEdit(this.colorEdit);
        }
        if (this.isPreviewEnabled) {
            this.colorPreview = (LinearLayout) View.inflate(context, R.layout.color_preview, null);
            this.colorPreview.setVisibility(8);
            this.pickerContainer.addView(this.colorPreview);
            if (this.initialColor.length == 0) {
                ImageView colorImage = (ImageView) View.inflate(context, R.layout.color_selector, null);
                colorImage.setImageDrawable(new ColorDrawable(-1));
            } else {
                for (int i = 0; i < this.initialColor.length && i < this.pickerCount && this.initialColor[i] != null; i++) {
                    LinearLayout colorLayout = (LinearLayout) View.inflate(context, R.layout.color_selector, null);
                    ImageView colorImage2 = (ImageView) colorLayout.findViewById(R.id.image_preview);
                    colorImage2.setImageDrawable(new ColorDrawable(this.initialColor[i].intValue()));
                    this.colorPreview.addView(colorLayout);
                }
            }
            this.colorPreview.setVisibility(0);
            this.colorPickerView.setColorPreview(this.colorPreview, getStartOffset(this.initialColor));
        }
        return this.builder.create();
    }

    public EditText getColorEdit() {
        return this.colorEdit;
    }

    private Integer getStartOffset(Integer[] colors) {
        int start = 0;
        for (int i = 0; i < colors.length && colors[i] != null; i++) {
            start = Integer.valueOf((i + 1) / 2);
        }
        return start;
    }

    private int getStartColor(Integer[] colors) {
        Integer startColor = getStartOffset(colors);
        if (startColor == null) {
            return -1;
        }
        return colors[startColor.intValue()].intValue();
    }

    private static int getDimensionAsPx(Context context, int rid) {
        return (int) (context.getResources().getDimension(rid) + 0.5f);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void positiveButtonOnClick(DialogInterface dialog, ColorPickerClickListener onClickListener) {
        int selectedColor = this.colorPickerView.getSelectedColor();
        Integer[] allColors = this.colorPickerView.getAllColors();
        onClickListener.onClick(dialog, selectedColor, allColors);
    }
}
