package com.myopicmobile.textwarrior.common;

import java.util.ArrayList;
/* loaded from: classes.dex */
public class Document extends TextBuffer {
    private boolean _isWordWrap = false;
    private TextFieldMetrics _metrics;
    private ArrayList<Integer> _rowTable;

    /* loaded from: classes.dex */
    public interface TextFieldMetrics {
        int getAdvance(char c);

        int getRowWidth();
    }

    public Document(TextFieldMetrics metrics) {
        this._metrics = metrics;
        resetRowTable();
    }

    public void setText(CharSequence text) {
        int lineCount = 1;
        int len = text.length();
        char[] ca = new char[TextBuffer.memoryNeeded(len)];
        for (int i = 0; i < len; i++) {
            ca[i] = text.charAt(i);
            if (text.charAt(i) == '\n') {
                lineCount++;
            }
        }
        setBuffer(ca, len, lineCount);
    }

    private void resetRowTable() {
        ArrayList<Integer> rowTable = new ArrayList<>();
        rowTable.add(0);
        this._rowTable = rowTable;
    }

    public void setMetrics(TextFieldMetrics metrics) {
        this._metrics = metrics;
    }

    public void setWordWrap(boolean enable) {
        if (enable && !this._isWordWrap) {
            this._isWordWrap = true;
            analyzeWordWrap();
        } else if (!enable && this._isWordWrap) {
            this._isWordWrap = false;
            analyzeWordWrap();
        }
    }

    public boolean isWordWrap() {
        return this._isWordWrap;
    }

    @Override // com.myopicmobile.textwarrior.common.TextBuffer
    public synchronized void delete(int charOffset, int totalChars, long timestamp, boolean undoable) {
        super.delete(charOffset, totalChars, timestamp, undoable);
        int startRow = findRowNumber(charOffset);
        int analyzeEnd = findNextLineFrom(charOffset);
        updateWordWrapAfterEdit(startRow, analyzeEnd, -totalChars);
    }

    @Override // com.myopicmobile.textwarrior.common.TextBuffer
    public synchronized void insert(char[] c, int charOffset, long timestamp, boolean undoable) {
        super.insert(c, charOffset, timestamp, undoable);
        int startRow = findRowNumber(charOffset);
        int analyzeEnd = findNextLineFrom(c.length + charOffset);
        updateWordWrapAfterEdit(startRow, analyzeEnd, c.length);
    }

    @Override // com.myopicmobile.textwarrior.common.TextBuffer
    synchronized void shiftGapStart(int displacement) {
        super.shiftGapStart(displacement);
        if (displacement != 0) {
            int startOffset = displacement > 0 ? this._gapStartIndex - displacement : this._gapStartIndex;
            int startRow = findRowNumber(startOffset);
            int analyzeEnd = findNextLineFrom(this._gapStartIndex);
            updateWordWrapAfterEdit(startRow, analyzeEnd, displacement);
        }
    }

    private int findNextLineFrom(int charOffset) {
        int lineEnd = logicalToRealIndex(charOffset);
        while (lineEnd < this._contents.length) {
            if (lineEnd == this._gapStartIndex) {
                lineEnd = this._gapEndIndex;
            }
            if (this._contents[lineEnd] == '\n' || this._contents[lineEnd] == 65535) {
                break;
            }
            lineEnd++;
        }
        return realToLogicalIndex(lineEnd) + 1;
    }

    private void updateWordWrapAfterEdit(int startRow, int analyzeEnd, int delta) {
        if (startRow > 0) {
            startRow--;
        }
        int analyzeStart = this._rowTable.get(startRow).intValue();
        removeRowMetadata(startRow + 1, analyzeEnd - delta);
        adjustOffsetOfRowsFrom(startRow + 1, delta);
        analyzeWordWrap(startRow + 1, analyzeStart, analyzeEnd);
    }

    private void removeRowMetadata(int fromRow, int endOffset) {
        while (fromRow < this._rowTable.size() && this._rowTable.get(fromRow).intValue() <= endOffset) {
            this._rowTable.remove(fromRow);
        }
    }

    private void adjustOffsetOfRowsFrom(int fromRow, int offset) {
        for (int i = fromRow; i < this._rowTable.size(); i++) {
            this._rowTable.set(i, Integer.valueOf(this._rowTable.get(i).intValue() + offset));
        }
    }

    public void analyzeWordWrap() {
        resetRowTable();
        if (this._isWordWrap && !hasMinimumWidthForWordWrap()) {
            if (this._metrics.getRowWidth() > 0) {
                TextWarriorException.fail("Text field has non-zero width but still too small for word wrap");
                return;
            }
            return;
        }
        analyzeWordWrap(1, 0, getTextLength());
    }

    private boolean hasMinimumWidthForWordWrap() {
        int maxWidth = this._metrics.getRowWidth();
        return maxWidth >= this._metrics.getAdvance('M') * 2;
    }

    private void analyzeWordWrap(int rowIndex, int startOffset, int endOffset) {
        if (!this._isWordWrap) {
            int offset = logicalToRealIndex(startOffset);
            int end = logicalToRealIndex(endOffset);
            ArrayList<Integer> rowTable = new ArrayList<>();
            while (offset < end) {
                if (offset == this._gapStartIndex) {
                    offset = this._gapEndIndex;
                }
                if (this._contents[offset] == '\n') {
                    rowTable.add(Integer.valueOf(realToLogicalIndex(offset) + 1));
                }
                offset++;
            }
            this._rowTable.addAll(rowIndex, rowTable);
        } else if (!hasMinimumWidthForWordWrap()) {
            TextWarriorException.fail("Not enough space to do word wrap");
        } else {
            ArrayList<Integer> rowTable2 = new ArrayList<>();
            int offset2 = logicalToRealIndex(startOffset);
            int end2 = logicalToRealIndex(endOffset);
            int potentialBreakPoint = startOffset;
            int wordExtent = 0;
            int maxWidth = this._metrics.getRowWidth();
            int remainingWidth = maxWidth;
            while (offset2 < end2) {
                if (offset2 == this._gapStartIndex) {
                    offset2 = this._gapEndIndex;
                }
                char c = this._contents[offset2];
                wordExtent += this._metrics.getAdvance(c);
                boolean isWhitespace = c == ' ' || c == '\t' || c == '\n' || c == 65535;
                if (isWhitespace) {
                    if (wordExtent <= remainingWidth) {
                        remainingWidth -= wordExtent;
                    } else if (wordExtent > maxWidth) {
                        int current = logicalToRealIndex(potentialBreakPoint);
                        remainingWidth = maxWidth;
                        if (potentialBreakPoint != startOffset && (rowTable2.isEmpty() || potentialBreakPoint != rowTable2.get(rowTable2.size() - 1).intValue())) {
                            rowTable2.add(Integer.valueOf(potentialBreakPoint));
                        }
                        while (current <= offset2) {
                            if (current == this._gapStartIndex) {
                                current = this._gapEndIndex;
                            }
                            int advance = this._metrics.getAdvance(this._contents[current]);
                            if (advance > remainingWidth) {
                                rowTable2.add(Integer.valueOf(realToLogicalIndex(current)));
                                remainingWidth = maxWidth - advance;
                            } else {
                                remainingWidth -= advance;
                            }
                            current++;
                        }
                    } else {
                        rowTable2.add(Integer.valueOf(potentialBreakPoint));
                        remainingWidth = maxWidth - wordExtent;
                    }
                    wordExtent = 0;
                    potentialBreakPoint = realToLogicalIndex(offset2) + 1;
                }
                if (c == '\n') {
                    rowTable2.add(Integer.valueOf(potentialBreakPoint));
                    remainingWidth = maxWidth;
                }
                offset2++;
            }
            this._rowTable.addAll(rowIndex, rowTable2);
        }
    }

    public String getRow(int rowNumber) {
        int rowSize = getRowSize(rowNumber);
        if (rowSize == 0) {
            return new String();
        }
        int startIndex = this._rowTable.get(rowNumber).intValue();
        return subSequence(startIndex, rowSize).toString();
    }

    public int getRowSize(int rowNumber) {
        if (isInvalidRow(rowNumber)) {
            return 0;
        }
        if (rowNumber != this._rowTable.size() - 1) {
            return this._rowTable.get(rowNumber + 1).intValue() - this._rowTable.get(rowNumber).intValue();
        }
        return getTextLength() - this._rowTable.get(rowNumber).intValue();
    }

    public int getRowCount() {
        return this._rowTable.size();
    }

    public int getRowOffset(int rowNumber) {
        if (isInvalidRow(rowNumber)) {
            return -1;
        }
        return this._rowTable.get(rowNumber).intValue();
    }

    public int findRowNumber(int charOffset) {
        if (isValid(charOffset)) {
            int right = this._rowTable.size() - 1;
            int left = 0;
            while (right >= left) {
                int mid = (left + right) / 2;
                int nextLineOffset = mid + 1 < this._rowTable.size() ? this._rowTable.get(mid + 1).intValue() : getTextLength();
                if (charOffset < this._rowTable.get(mid).intValue() || charOffset >= nextLineOffset) {
                    if (charOffset >= nextLineOffset) {
                        left = mid + 1;
                    } else {
                        right = mid - 1;
                    }
                } else {
                    return mid;
                }
            }
            return -1;
        }
        return -1;
    }

    protected boolean isInvalidRow(int rowNumber) {
        return rowNumber < 0 || rowNumber >= this._rowTable.size();
    }
}
