package com.myopicmobile.textwarrior.common;

import java.util.List;
import java.util.Vector;
/* loaded from: classes.dex */
public class TextBuffer implements CharSequence {
    protected static final int MIN_GAP_SIZE = 50;
    private int _allocMultiplier;
    private TextBufferCache _cache;
    protected char[] _contents = new char[51];
    protected int _gapEndIndex;
    protected int _gapStartIndex;
    protected int _lineCount;
    protected List<Pair> _spans;
    private UndoStack _undoStack;

    @Override // java.lang.CharSequence
    public int length() {
        return getTextLength() - 1;
    }

    public TextBuffer() {
        this._contents[50] = Language.EOF;
        this._allocMultiplier = 1;
        this._gapStartIndex = 0;
        this._gapEndIndex = 50;
        this._lineCount = 1;
        this._cache = new TextBufferCache();
        this._undoStack = new UndoStack(this);
    }

    public static int memoryNeeded(int textSize) {
        long bufferSize = textSize + 50 + 1;
        if (bufferSize < 2147483647L) {
            return (int) bufferSize;
        }
        return -1;
    }

    public synchronized void setBuffer(char[] newBuffer, int textSize, int lineCount) {
        this._contents = newBuffer;
        initGap(textSize);
        this._lineCount = lineCount;
        this._allocMultiplier = 1;
    }

    public synchronized void setBuffer(char[] newBuffer) {
        int lineCount = 1;
        int len = newBuffer.length;
        for (char c : newBuffer) {
            if (c == '\n') {
                lineCount++;
            }
        }
        setBuffer(newBuffer, len, lineCount);
    }

    public synchronized String getLine(int lineNumber) {
        String charSequence;
        int startIndex = getLineOffset(lineNumber);
        if (startIndex < 0) {
            charSequence = new String();
        } else {
            int lineSize = getLineSize(lineNumber);
            charSequence = subSequence(startIndex, lineSize).toString();
        }
        return charSequence;
    }

    public synchronized int getLineOffset(int lineNumber) {
        int offset;
        if (lineNumber < 0) {
            offset = -1;
        } else {
            Pair cachedEntry = this._cache.getNearestLine(lineNumber);
            int cachedLine = cachedEntry.getFirst();
            int cachedOffset = cachedEntry.getSecond();
            if (lineNumber > cachedLine) {
                offset = findCharOffset(lineNumber, cachedLine, cachedOffset);
            } else if (lineNumber < cachedLine) {
                offset = findCharOffsetBackward(lineNumber, cachedLine, cachedOffset);
            } else {
                offset = cachedOffset;
            }
            if (offset >= 0) {
                this._cache.updateEntry(lineNumber, offset);
            }
        }
        return offset;
    }

    private int findCharOffset(int targetLine, int startLine, int startOffset) {
        int workingLine = startLine;
        int offset = logicalToRealIndex(startOffset);
        TextWarriorException.assertVerbose(isValid(startOffset), "findCharOffsetBackward: Invalid startingOffset given");
        while (workingLine < targetLine && offset < this._contents.length) {
            if (this._contents[offset] == '\n') {
                workingLine++;
            }
            offset++;
            if (offset == this._gapStartIndex) {
                offset = this._gapEndIndex;
            }
        }
        if (workingLine != targetLine) {
            return -1;
        }
        return realToLogicalIndex(offset);
    }

    private int findCharOffsetBackward(int targetLine, int startLine, int startOffset) {
        if (targetLine == 0) {
            return 0;
        }
        TextWarriorException.assertVerbose(isValid(startOffset), "findCharOffsetBackward: Invalid startOffset given");
        int workingLine = startLine;
        int offset = logicalToRealIndex(startOffset);
        while (workingLine > targetLine - 1 && offset >= 0) {
            if (offset == this._gapEndIndex) {
                offset = this._gapStartIndex;
            }
            offset--;
            if (this._contents[offset] == '\n') {
                workingLine--;
            }
        }
        if (offset >= 0) {
            int charOffset = realToLogicalIndex(offset);
            return charOffset + 1;
        }
        TextWarriorException.assertVerbose(false, "findCharOffsetBackward: Invalid cache entry or line arguments");
        return -1;
    }

    public synchronized int findLineNumber(int charOffset) {
        int line;
        if (isValid(charOffset)) {
            Pair cachedEntry = this._cache.getNearestCharOffset(charOffset);
            line = cachedEntry.getFirst();
            int offset = logicalToRealIndex(cachedEntry.getSecond());
            int targetOffset = logicalToRealIndex(charOffset);
            int lastKnownLine = -1;
            int lastKnownCharOffset = -1;
            if (targetOffset > offset) {
                while (offset < targetOffset && offset < this._contents.length) {
                    if (this._contents[offset] == '\n') {
                        line++;
                        lastKnownLine = line;
                        lastKnownCharOffset = realToLogicalIndex(offset) + 1;
                    }
                    offset++;
                    if (offset == this._gapStartIndex) {
                        offset = this._gapEndIndex;
                    }
                }
            } else if (targetOffset < offset) {
                while (offset > targetOffset && offset > 0) {
                    if (offset == this._gapEndIndex) {
                        offset = this._gapStartIndex;
                    }
                    offset--;
                    if (this._contents[offset] == '\n') {
                        lastKnownLine = line;
                        lastKnownCharOffset = realToLogicalIndex(offset) + 1;
                        line--;
                    }
                }
            }
            if (offset != targetOffset) {
                line = -1;
            } else if (lastKnownLine != -1) {
                this._cache.updateEntry(lastKnownLine, lastKnownCharOffset);
            }
        } else {
            line = -1;
        }
        return line;
    }

    public synchronized int getLineSize(int lineNumber) {
        int lineLength;
        lineLength = 0;
        int pos = getLineOffset(lineNumber);
        if (pos != -1) {
            int pos2 = logicalToRealIndex(pos);
            while (this._contents[pos2] != '\n' && this._contents[pos2] != 65535) {
                lineLength++;
                pos2++;
                if (pos2 == this._gapStartIndex) {
                    pos2 = this._gapEndIndex;
                }
            }
            lineLength++;
        }
        return lineLength;
    }

    @Override // java.lang.CharSequence
    public synchronized char charAt(int charOffset) {
        return this._contents[logicalToRealIndex(charOffset)];
    }

    @Override // java.lang.CharSequence
    public synchronized CharSequence subSequence(int charOffset, int maxChars) {
        String str;
        if (!isValid(charOffset) || maxChars <= 0) {
            str = new String();
        } else {
            int totalChars = maxChars;
            if (charOffset + totalChars > getTextLength()) {
                totalChars = getTextLength() - charOffset;
            }
            int realIndex = logicalToRealIndex(charOffset);
            char[] chars = new char[totalChars];
            for (int i = 0; i < totalChars; i++) {
                chars[i] = this._contents[realIndex];
                realIndex++;
                if (realIndex == this._gapStartIndex) {
                    realIndex = this._gapEndIndex;
                }
            }
            str = new String(chars);
        }
        return str;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public char[] gapSubSequence(int charCount) {
        char[] chars = new char[charCount];
        for (int i = 0; i < charCount; i++) {
            chars[i] = this._contents[this._gapStartIndex + i];
        }
        return chars;
    }

    public synchronized void insert(char[] c, int charOffset, long timestamp, boolean undoable) {
        if (undoable) {
            this._undoStack.captureInsert(charOffset, c.length, timestamp);
        }
        int insertIndex = logicalToRealIndex(charOffset);
        if (insertIndex != this._gapEndIndex) {
            if (isBeforeGap(insertIndex)) {
                shiftGapLeft(insertIndex);
            } else {
                shiftGapRight(insertIndex);
            }
        }
        if (c.length >= gapSize()) {
            growBufferBy(c.length - gapSize());
        }
        for (int i = 0; i < c.length; i++) {
            if (c[i] == '\n') {
                this._lineCount++;
            }
            this._contents[this._gapStartIndex] = c[i];
            this._gapStartIndex++;
        }
        this._cache.invalidateCache(charOffset);
        onAdd(charOffset, c.length);
    }

    public synchronized void delete(int charOffset, int totalChars, long timestamp, boolean undoable) {
        if (undoable) {
            this._undoStack.captureDelete(charOffset, totalChars, timestamp);
        }
        int newGapStart = charOffset + totalChars;
        if (newGapStart != this._gapStartIndex) {
            if (isBeforeGap(newGapStart)) {
                shiftGapLeft(newGapStart);
            } else {
                shiftGapRight(gapSize() + newGapStart);
            }
        }
        for (int i = 0; i < totalChars; i++) {
            this._gapStartIndex--;
            if (this._contents[this._gapStartIndex] == '\n') {
                this._lineCount--;
            }
        }
        this._cache.invalidateCache(charOffset);
        onDel(charOffset, totalChars);
    }

    private void onAdd(int charOffset, int totalChars) {
        Pair s = findSpan(charOffset);
        Pair p = this._spans.get(s.getFirst());
        p.setFirst(p.getFirst() + totalChars);
    }

    private void onDel(int charOffset, int totalChars) {
        int len = length();
        if (len == 0) {
            clearSpans();
            return;
        }
        Pair s = findSpan2(charOffset);
        if (totalChars == 1) {
            Pair p = this._spans.get(s.getFirst());
            if (p.getFirst() > 1) {
                p.setFirst(p.getFirst() - 1);
                return;
            } else {
                this._spans.remove(s.getFirst());
                return;
            }
        }
        int o = s.getSecond();
        int l = charOffset - o;
        Pair p2 = this._spans.get(s.getFirst());
        if (p2.getFirst() > l) {
            p2.setFirst(p2.getFirst() - l);
        } else {
            this._spans.remove(s.getFirst());
        }
        int totalChars2 = totalChars - l;
        if (totalChars2 > 0) {
            for (int i = s.getFirst(); i >= 0; i--) {
                Pair p1 = this._spans.get(i);
                int l2 = p1.getFirst();
                if (totalChars2 > l2) {
                    totalChars2 -= l2;
                    this._spans.remove(i);
                } else {
                    p1.setFirst(p1.getFirst() - totalChars2);
                    return;
                }
            }
        }
    }

    private Pair findSpan(int index) {
        int n = this._spans.size();
        int cur = 0;
        for (int i = 0; i < n; i++) {
            int l = this._spans.get(i).getFirst();
            cur += l;
            if (cur >= index) {
                return new Pair(i, cur - l);
            }
        }
        return new Pair(0, 0);
    }

    private Pair findSpan2(int index) {
        int n = this._spans.size();
        int cur = 0;
        for (int i = 0; i < n; i++) {
            int l = this._spans.get(i).getFirst();
            cur += l;
            if (cur > index) {
                return new Pair(i, cur - l);
            }
        }
        return new Pair(0, 0);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public synchronized void shiftGapStart(int displacement) {
        if (displacement >= 0) {
            onAdd(this._gapStartIndex, displacement);
            this._lineCount += countNewlines(this._gapStartIndex, displacement);
        } else {
            onDel(this._gapStartIndex, 0 - displacement);
            this._lineCount -= countNewlines(this._gapStartIndex + displacement, -displacement);
        }
        this._gapStartIndex += displacement;
        this._cache.invalidateCache(realToLogicalIndex(this._gapStartIndex - 1) + 1);
    }

    private int countNewlines(int start, int totalChars) {
        int newlines = 0;
        for (int i = start; i < start + totalChars; i++) {
            if (this._contents[i] == '\n') {
                newlines++;
            }
        }
        return newlines;
    }

    protected final void shiftGapLeft(int newGapStart) {
        while (this._gapStartIndex > newGapStart) {
            this._gapEndIndex--;
            this._gapStartIndex--;
            this._contents[this._gapEndIndex] = this._contents[this._gapStartIndex];
        }
    }

    protected final void shiftGapRight(int newGapEnd) {
        while (this._gapEndIndex < newGapEnd) {
            this._contents[this._gapStartIndex] = this._contents[this._gapEndIndex];
            this._gapStartIndex++;
            this._gapEndIndex++;
        }
    }

    protected void initGap(int contentsLength) {
        int toPosition = this._contents.length - 1;
        int toPosition2 = toPosition - 1;
        this._contents[toPosition] = Language.EOF;
        int fromPosition = contentsLength - 1;
        int fromPosition2 = fromPosition;
        while (fromPosition2 >= 0) {
            this._contents[toPosition2] = this._contents[fromPosition2];
            fromPosition2--;
            toPosition2--;
        }
        this._gapStartIndex = 0;
        this._gapEndIndex = toPosition2 + 1;
    }

    protected void growBufferBy(int minIncrement) {
        int increasedSize = minIncrement + (this._allocMultiplier * 50);
        char[] temp = new char[this._contents.length + increasedSize];
        for (int i = 0; i < this._gapStartIndex; i++) {
            temp[i] = this._contents[i];
        }
        for (int i2 = this._gapEndIndex; i2 < this._contents.length; i2++) {
            temp[i2 + increasedSize] = this._contents[i2];
        }
        this._gapEndIndex += increasedSize;
        this._contents = temp;
        this._allocMultiplier <<= 1;
    }

    public final synchronized int getTextLength() {
        return this._contents.length - gapSize();
    }

    public synchronized int getLineCount() {
        return this._lineCount;
    }

    public final synchronized boolean isValid(int charOffset) {
        boolean z;
        if (charOffset >= 0) {
            z = charOffset < getTextLength() ? true : true;
        }
        z = false;
        return z;
    }

    protected final int gapSize() {
        return this._gapEndIndex - this._gapStartIndex;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final int logicalToRealIndex(int i) {
        return isBeforeGap(i) ? i : i + gapSize();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final int realToLogicalIndex(int i) {
        return isBeforeGap(i) ? i : i - gapSize();
    }

    protected final boolean isBeforeGap(int i) {
        return i < this._gapStartIndex;
    }

    public void clearSpans() {
        this._spans = new Vector();
        this._spans.add(new Pair(length(), 0));
    }

    public List<Pair> getSpans() {
        return this._spans;
    }

    public void setSpans(List<Pair> spans) {
        this._spans = spans;
    }

    public boolean isBatchEdit() {
        return this._undoStack.isBatchEdit();
    }

    public void beginBatchEdit() {
        this._undoStack.beginBatchEdit();
    }

    public void endBatchEdit() {
        this._undoStack.endBatchEdit();
    }

    public boolean canUndo() {
        return this._undoStack.canUndo();
    }

    public boolean canRedo() {
        return this._undoStack.canRedo();
    }

    public int undo() {
        return this._undoStack.undo();
    }

    public int redo() {
        return this._undoStack.redo();
    }

    @Override // java.lang.CharSequence
    public String toString() {
        int len = getTextLength();
        StringBuffer buf = new StringBuffer();
        for (int i = 0; i < len; i++) {
            char c = charAt(i);
            if (c == 65535) {
                break;
            }
            buf.append(c);
        }
        return new String(buf);
    }
}
