package com.myopicmobile.textwarrior.common;

import java.util.LinkedList;
/* loaded from: classes.dex */
public class UndoStack {
    private TextBuffer _buf;
    private LinkedList<Command> _stack = new LinkedList<>();
    private boolean _isBatchEdit = false;
    private int _groupId = 0;
    private int _top = 0;
    long _lastEditTime = -1;

    public UndoStack(TextBuffer buf) {
        this._buf = buf;
    }

    public int undo() {
        if (canUndo()) {
            Command lastUndone = this._stack.get(this._top - 1);
            int group = lastUndone._group;
            do {
                Command c = this._stack.get(this._top - 1);
                if (c._group != group) {
                    break;
                }
                lastUndone = c;
                c.undo();
                this._top--;
            } while (canUndo());
            return lastUndone.findUndoPosition();
        }
        return -1;
    }

    public int redo() {
        if (canRedo()) {
            Command lastRedone = this._stack.get(this._top);
            int group = lastRedone._group;
            do {
                Command c = this._stack.get(this._top);
                if (c._group != group) {
                    break;
                }
                lastRedone = c;
                c.redo();
                this._top++;
            } while (canRedo());
            return lastRedone.findRedoPosition();
        }
        return -1;
    }

    public void captureInsert(int start, int length, long time) {
        boolean mergeSuccess = false;
        if (canUndo()) {
            Command c = this._stack.get(this._top - 1);
            if ((c instanceof InsertCommand) && c.merge(start, length, time)) {
                mergeSuccess = true;
            } else {
                c.recordData();
            }
        }
        if (!mergeSuccess) {
            push(new InsertCommand(start, length, this._groupId));
            if (!this._isBatchEdit) {
                this._groupId++;
            }
        }
        this._lastEditTime = time;
    }

    public void captureDelete(int start, int length, long time) {
        boolean mergeSuccess = false;
        if (canUndo()) {
            Command c = this._stack.get(this._top - 1);
            if ((c instanceof DeleteCommand) && c.merge(start, length, time)) {
                mergeSuccess = true;
            } else {
                c.recordData();
            }
        }
        if (!mergeSuccess) {
            push(new DeleteCommand(start, length, this._groupId));
            if (!this._isBatchEdit) {
                this._groupId++;
            }
        }
        this._lastEditTime = time;
    }

    private void push(Command c) {
        trimStack();
        this._top++;
        this._stack.add(c);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void trimStack() {
        while (this._stack.size() > this._top) {
            this._stack.removeLast();
        }
    }

    public final boolean canUndo() {
        return this._top > 0;
    }

    public final boolean canRedo() {
        return this._top < this._stack.size();
    }

    public boolean isBatchEdit() {
        return this._isBatchEdit;
    }

    public void beginBatchEdit() {
        this._isBatchEdit = true;
    }

    public void endBatchEdit() {
        this._isBatchEdit = false;
        this._groupId++;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public abstract class Command {
        public static final long MERGE_TIME = 1000000000;
        public String _data;
        public int _group;
        public int _length;
        public int _start;

        public abstract int findRedoPosition();

        public abstract int findUndoPosition();

        public abstract boolean merge(int i, int i2, long j);

        public abstract void recordData();

        public abstract void redo();

        public abstract void undo();

        private Command() {
        }
    }

    /* loaded from: classes.dex */
    private class InsertCommand extends Command {
        public InsertCommand(int start, int length, int groupNumber) {
            super();
            this._start = start;
            this._length = length;
            this._group = groupNumber;
        }

        @Override // com.myopicmobile.textwarrior.common.UndoStack.Command
        public boolean merge(int newStart, int length, long time) {
            if (UndoStack.this._lastEditTime >= 0 && time - UndoStack.this._lastEditTime < Command.MERGE_TIME && newStart == this._start + this._length) {
                this._length += length;
                UndoStack.this.trimStack();
                return true;
            }
            return false;
        }

        @Override // com.myopicmobile.textwarrior.common.UndoStack.Command
        public void recordData() {
            this._data = UndoStack.this._buf.subSequence(this._start, this._length).toString();
        }

        @Override // com.myopicmobile.textwarrior.common.UndoStack.Command
        public void undo() {
            if (this._data != null) {
                UndoStack.this._buf.delete(this._start, this._length, 0L, false);
                return;
            }
            recordData();
            UndoStack.this._buf.shiftGapStart(-this._length);
        }

        @Override // com.myopicmobile.textwarrior.common.UndoStack.Command
        public void redo() {
            UndoStack.this._buf.insert(this._data.toCharArray(), this._start, 0L, false);
        }

        @Override // com.myopicmobile.textwarrior.common.UndoStack.Command
        public int findRedoPosition() {
            return this._start + this._length;
        }

        @Override // com.myopicmobile.textwarrior.common.UndoStack.Command
        public int findUndoPosition() {
            return this._start;
        }
    }

    /* loaded from: classes.dex */
    private class DeleteCommand extends Command {
        public DeleteCommand(int start, int length, int seqNumber) {
            super();
            this._start = start;
            this._length = length;
            this._group = seqNumber;
        }

        @Override // com.myopicmobile.textwarrior.common.UndoStack.Command
        public boolean merge(int newStart, int length, long time) {
            if (UndoStack.this._lastEditTime >= 0 && time - UndoStack.this._lastEditTime < Command.MERGE_TIME && newStart == ((this._start - this._length) - length) + 1) {
                this._start = newStart;
                this._length += length;
                UndoStack.this.trimStack();
                return true;
            }
            return false;
        }

        @Override // com.myopicmobile.textwarrior.common.UndoStack.Command
        public void recordData() {
            this._data = new String(UndoStack.this._buf.gapSubSequence(this._length));
        }

        @Override // com.myopicmobile.textwarrior.common.UndoStack.Command
        public void undo() {
            if (this._data != null) {
                UndoStack.this._buf.insert(this._data.toCharArray(), this._start, 0L, false);
                return;
            }
            recordData();
            UndoStack.this._buf.shiftGapStart(this._length);
        }

        @Override // com.myopicmobile.textwarrior.common.UndoStack.Command
        public void redo() {
            UndoStack.this._buf.delete(this._start, this._length, 0L, false);
        }

        @Override // com.myopicmobile.textwarrior.common.UndoStack.Command
        public int findRedoPosition() {
            return this._start;
        }

        @Override // com.myopicmobile.textwarrior.common.UndoStack.Command
        public int findUndoPosition() {
            return this._start + this._length;
        }
    }
}
