package com.pixplicity.sharp;

import android.annotation.TargetApi;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Picture;
import android.graphics.Rect;
import android.graphics.drawable.PictureDrawable;
import android.os.Build;
import android.os.Looper;
import android.support.annotation.Nullable;
import android.util.Log;
import android.view.View;
/* loaded from: classes.dex */
public class SharpDrawable extends PictureDrawable {
    private Bitmap mCacheBitmap;
    private Rect mCacheBounds;
    private float mCacheScale;
    private boolean mCaching;
    private float mScaleX;
    private float mScaleY;
    private static final String TAG = SharpDrawable.class.getSimpleName();
    private static final Bitmap.Config CACHE_CONFIG = Bitmap.Config.ARGB_8888;

    @TargetApi(11)
    public SharpDrawable(@Nullable Picture picture) {
        super(picture);
        this.mScaleX = 1.0f;
        this.mScaleY = 1.0f;
        this.mCaching = false;
        this.mCacheScale = 1.0f;
    }

    @TargetApi(11)
    public SharpDrawable(@Nullable View view, @Nullable Picture picture) {
        super(picture);
        this.mScaleX = 1.0f;
        this.mScaleY = 1.0f;
        this.mCaching = false;
        this.mCacheScale = 1.0f;
        prepareView(view);
    }

    public static void prepareView(@Nullable final View view) {
        if (view != null && Build.VERSION.SDK_INT >= 11) {
            if (Looper.myLooper() == Looper.getMainLooper()) {
                view.setLayerType(1, null);
            } else {
                view.post(new Runnable() { // from class: com.pixplicity.sharp.SharpDrawable.1
                    @Override // java.lang.Runnable
                    public void run() {
                        view.setLayerType(1, null);
                    }
                });
            }
        }
    }

    @Override // android.graphics.drawable.PictureDrawable, android.graphics.drawable.Drawable
    public void draw(Canvas parentCanvas) {
        long start = System.currentTimeMillis();
        Picture picture = getPicture();
        if (picture != null) {
            Rect bounds = getBounds();
            Canvas canvas = null;
            if (this.mCaching) {
                if (this.mCacheBitmap == null || this.mCacheBounds == null || !this.mCacheBounds.equals(bounds)) {
                    resetCache();
                    int w = (int) (bounds.width() * this.mCacheScale);
                    int h = (int) (bounds.height() * this.mCacheScale);
                    Log.v(TAG, "cache bitmap " + w + "x" + h);
                    this.mCacheBitmap = Bitmap.createBitmap(w, h, CACHE_CONFIG);
                    if (this.mCacheBounds == null) {
                        this.mCacheBounds = new Rect(bounds);
                    } else {
                        this.mCacheBounds.set(bounds);
                    }
                    canvas = new Canvas(this.mCacheBitmap);
                    canvas.save();
                    canvas.scale(this.mCacheScale, this.mCacheScale);
                }
            } else {
                canvas = parentCanvas;
            }
            if (canvas != null) {
                canvas.save();
                canvas.clipRect(bounds);
                Log.v(TAG, "canvas " + canvas.getWidth() + "x" + canvas.getHeight());
                Log.v(TAG, "bounds " + bounds.toString());
                canvas.translate(bounds.left, bounds.top);
                canvas.scale(this.mScaleX, this.mScaleY, 0.0f, 0.0f);
                canvas.drawPicture(picture);
                canvas.restore();
            }
            if (this.mCacheBitmap != null) {
                if (canvas != null) {
                    canvas.restore();
                }
                parentCanvas.save();
                parentCanvas.scale(1.0f / this.mCacheScale, 1.0f / this.mCacheScale, 0.0f, 0.0f);
                parentCanvas.drawBitmap(this.mCacheBitmap, 0.0f, 0.0f, (Paint) null);
                parentCanvas.restore();
            }
        }
        Log.v(TAG, "Drawing " + hashCode() + " complete in " + (System.currentTimeMillis() - start) + " ms.");
    }

    @Override // android.graphics.drawable.Drawable
    public void setBounds(int left, int top, int right, int bottom) {
        Picture picture = getPicture();
        int width = right - left;
        int height = bottom - top;
        this.mScaleX = width / picture.getWidth();
        this.mScaleY = height / picture.getHeight();
        super.setBounds(left, top, right, bottom);
    }

    public void setCaching(boolean caching) {
        this.mCaching = caching;
    }

    public void setCacheScale(float scale) {
        this.mCacheScale = scale;
    }

    public void resetCache() {
        if (!this.mCaching) {
            throw new IllegalStateException("Cache is not enabled");
        }
        if (this.mCacheBitmap != null) {
            this.mCacheBitmap.recycle();
            this.mCacheBitmap = null;
        }
    }
}
